@@ -12,29 +12,32 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-use crate::keys::extract_keypair;
-use crate::util::{format_output, Output, OutputKind};
+use crate::{
+    keys::extract_keypair,
+    util::{format_output, Output, OutputKind},
+};
 use nkeys::{KeyPair, KeyPairType};
-use serde::de::DeserializeOwned;
-use serde::{Deserialize, Serialize};
+use serde::{de::DeserializeOwned, Deserialize, Serialize};
 use serde_json::json;
-use std::collections::HashMap;
-use std::fs::File;
-use std::io::Read;
-use std::io::Write;
-use std::path::PathBuf;
-use structopt::clap::AppSettings;
-use structopt::StructOpt;
+use std::{
+    collections::HashMap,
+    fs::File,
+    io::{Read, Write},
+    path::PathBuf,
+};
+use structopt::{clap::AppSettings, StructOpt};
 use term_table::{
     row::Row,
     table_cell::{Alignment, TableCell},
     Table,
 };
-use wascap::caps::*;
-use wascap::jwt::{
-    Account, Actor, CapabilityProvider, Claims, Operator, Token, TokenValidation, WascapEntity,
+use wascap::{
+    caps::*,
+    jwt::{
+        Account, Actor, CapabilityProvider, Claims, Operator, Token, TokenValidation, WascapEntity,
+    },
+    wasm::{days_from_now_to_jwt_time, sign_buffer_with_claims},
 };
-use wascap::wasm::{days_from_now_to_jwt_time, sign_buffer_with_claims};
 
 #[derive(Debug, StructOpt, Clone)]
 #[structopt(
@@ -104,6 +107,10 @@ pub(crate) struct InspectCommand {
     #[structopt(long = "insecure")]
     insecure: bool,
 
+    /// skip the local OCI cache
+    #[structopt(long = "no-cache")]
+    no_cache: bool,
+
     #[structopt(flatten)]
     pub(crate) output: Output,
 }
@@ -674,27 +681,19 @@ fn sign_file(cmd: SignCommand) -> Result<String, Box<dyn ::std::error::Error>> {
 async fn get_caps(
     cmd: &InspectCommand,
 ) -> Result<Option<Token<Actor>>, Box<dyn ::std::error::Error>> {
-    let module_bytes = match File::open(&cmd.module) {
-        Ok(mut f) => {
-            let mut buf = Vec::new();
-            f.read_to_end(&mut buf).unwrap();
-            buf
-        }
-        Err(_) => {
-            crate::reg::pull_artifact(
-                cmd.module.to_string(),
-                cmd.digest.clone(),
-                cmd.allow_latest,
-                cmd.user.clone(),
-                cmd.password.clone(),
-                cmd.insecure,
-            )
-            .await?
-        }
-    };
+    let artifact_bytes = crate::reg::get_artifact(
+        cmd.module.to_string(),
+        cmd.digest.clone(),
+        cmd.allow_latest,
+        cmd.user.clone(),
+        cmd.password.clone(),
+        cmd.insecure,
+        cmd.no_cache,
+    )
+    .await?;
 
     // Extract will return an error if it encounters an invalid hash in the claims
-    let claims = wascap::wasm::extract_claims(&module_bytes);
+    let claims = wascap::wasm::extract_claims(&artifact_bytes);
     match claims {
         Ok(token) => Ok(token),
         Err(e) => Err(Box::new(e)),
@@ -971,6 +970,7 @@ mod test {
             "--allow-latest",
             "--insecure",
             "--jwt-only",
+            "--no-cache",
         ])
         .unwrap();
 
@@ -984,6 +984,7 @@ mod test {
                 password,
                 insecure,
                 output,
+                no_cache,
             }) => {
                 assert_eq!(module, SUBSCRIBER_OCI);
                 assert_eq!(
@@ -996,6 +997,7 @@ mod test {
                 assert!(allow_latest);
                 assert!(insecure);
                 assert!(jwt_only);
+                assert!(no_cache);
             }
             cmd => panic!("claims constructed incorrect command: {:?}", cmd),
         }
@@ -1015,6 +1017,7 @@ mod test {
             "--allow-latest",
             "--insecure",
             "--jwt-only",
+            "--no-cache",
         ])
         .unwrap();
 
@@ -1028,6 +1031,7 @@ mod test {
                 password,
                 insecure,
                 output,
+                no_cache,
             }) => {
                 assert_eq!(module, SUBSCRIBER_OCI);
                 assert_eq!(
@@ -1040,6 +1044,7 @@ mod test {
                 assert!(allow_latest);
                 assert!(insecure);
                 assert!(jwt_only);
+                assert!(no_cache);
             }
             cmd => panic!("claims constructed incorrect command: {:?}", cmd),
         }
