@@ -1,11 +1,12 @@
 extern crate wasmcloud_control_interface;
-use crate::util::{format_optional, format_output, OutputKind};
+use crate::{
+    id::{ModuleId, ServiceId},
+    util::{format_optional, format_output, OutputKind},
+};
 use serde_json::json;
 use term_table::{row::Row, table_cell::*, Table};
 use wasmcloud_control_interface::*;
 
-use super::id::{ModuleId, ServiceId};
-
 pub(crate) fn get_hosts_output(hosts: Vec<Host>, output_kind: &OutputKind) -> String {
     match *output_kind {
         OutputKind::Text => hosts_table(hosts),
@@ -295,7 +296,7 @@ pub(crate) fn claims_table(list: GetClaimsResponse) -> String {
             ),
         ]));
         table.add_row(Row::new(vec![TableCell::new_with_alignment(
-            format!(""),
+            String::new(),
             2,
             Alignment::Center,
         )]));
