@@ -1,16 +1,13 @@
 extern crate oci_distribution;
-use crate::util::{format_output, Output, OutputKind};
+
+use crate::util::{cached_file, format_output, Output, OutputKind};
 use log::{debug, info, warn};
-use oci_distribution::client::*;
-use oci_distribution::secrets::RegistryAuth;
-use oci_distribution::Reference;
+use oci_distribution::{client::*, secrets::RegistryAuth, Reference};
 use provider_archive::ProviderArchive;
 use serde_json::json;
 use spinners::{Spinner, Spinners};
-use std::fs::File;
-use std::io::prelude::*;
-use structopt::clap::AppSettings;
-use structopt::StructOpt;
+use std::{fs::File, io::prelude::*};
+use structopt::{clap::AppSettings, StructOpt};
 
 const PROVIDER_ARCHIVE_MEDIA_TYPE: &str = "application/vnd.wasmcloud.provider.archive.layer.v1+par";
 const PROVIDER_ARCHIVE_CONFIG_MEDIA_TYPE: &str =
@@ -187,6 +184,30 @@ pub(crate) async fn handle_pull(cmd: PullCommand) -> Result<String, Box<dyn ::st
     ))
 }
 
+/// Attempts to return a local artifact, then a cached one.
+/// Falls back to pull from registry if neither is found.
+pub(crate) async fn get_artifact(
+    url: String,
+    digest: Option<String>,
+    allow_latest: bool,
+    user: Option<String>,
+    password: Option<String>,
+    insecure: bool,
+    no_cache: bool,
+) -> Result<Vec<u8>, Box<dyn ::std::error::Error>> {
+    if let Ok(mut local_artifact) = File::open(url.clone()) {
+        let mut buf = Vec::new();
+        local_artifact.read_to_end(&mut buf)?;
+        Ok(buf)
+    } else if let (Ok(mut cached_artifact), false) = (File::open(cached_file(&url)), no_cache) {
+        let mut buf = Vec::new();
+        cached_artifact.read_to_end(&mut buf)?;
+        Ok(buf)
+    } else {
+        pull_artifact(url.clone(), digest, allow_latest, user, password, insecure).await
+    }
+}
+
 pub(crate) async fn pull_artifact(
     url: String,
     digest: Option<String>,
@@ -287,8 +308,7 @@ pub(crate) fn write_artifact(
             .split('/')
             .collect::<Vec<_>>()
             .pop()
-            .unwrap()
-            .to_string(),
+            .unwrap(),
         file_extension
     ));
     let mut f = File::create(outfile.clone())?;
