@@ -1,12 +1,9 @@
 use nats::asynk::Connection;
 use serde::{Deserialize, Serialize};
-use std::collections::HashMap;
-use std::error::Error;
-use std::fmt;
-use std::fs::File;
-use std::io::Read;
-use std::path::PathBuf;
-use std::str::FromStr;
+use std::{
+    collections::HashMap, env::temp_dir, error::Error, fmt, fs::File, io::Read, path::PathBuf,
+    str::FromStr,
+};
 use structopt::StructOpt;
 use term_table::{Table, TableStyle};
 
@@ -248,3 +245,20 @@ pub(crate) async fn nats_client_from_opts(
     };
     Ok(nc)
 }
+
+pub(crate) const OCI_CACHE_DIR: &str = "wasmcloud_ocicache";
+
+pub(crate) fn cached_file(img: &str) -> PathBuf {
+    let path = temp_dir();
+    let path = path.join(OCI_CACHE_DIR);
+    let _ = ::std::fs::create_dir_all(&path);
+    // should produce a file like wasmcloud_azurecr_io_kvcounter_v1.bin
+    let mut path = path.join(img_name_to_file_name(img));
+    path.set_extension("bin");
+
+    path
+}
+
+pub(crate) fn img_name_to_file_name(img: &str) -> String {
+    img.replace(":", "_").replace("/", "_").replace(".", "_")
+}
